==> e2guardian_5.3.4.orig.tar.gz: e2guardian-5.3.4/README.md <==
# [E2Guardian](http://e2guardian.org) 

This is the v5 production version - v5.3.4 

Note that large sections of the code has been re-written and there are
significant changes to the configuration files in this release.

Note: Configuration files in this version are not backward compatable
with v4 configuration files.

Please read notes/NEWIN_v5 before installing.

**For copyright go to: http://e2guardian.org**

e2guardian is a content filtering proxy that can work in 
explicit and transparent proxy mode or as a ICAP server mode.
More information can be found in the "notes" subdirectory of the distribution, 
and the comments in the configuration and list files themselves.

e2guardian is a fork of [DansGuardian](http://dansguardian.org) and the 
maintainers fully acknowledge the work carried out by and the copyright 
of Daniel Baron and other contributors to the Dansguardian project.

Read the INSTALL for installation instructions.

## Contributing

Github: https://github.com/e2guardian

*	v5develop is used to develop new features
*	Bugfixes primarily occurs in the version branch 

## Bugs and Feature Requests

Github: https://github.com/e2guardian/e2guardian/issues

Codacy Badge:
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/92742338bce249c6a52739d0343dabfa)](https://www.codacy.com/app/numsys/e2guardian?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=e2guardian/e2guardian&amp;utm_campaign=Badge_Grade)

## Community

*	 Join the [Community
    Forum](https://groups.google.com/forum/#!forum/e2guardian).

## License

Copyright 2018, [Frederic Bourgeois](http://numsys.eu), [E2BN Protex](http://protex.e2bn.org) Ltd and others.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License version 2 as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

In addition, as a special exception, the copyright holders
of this work, give permission to link the code of its release of e2guardian
with the OpenSSL project's "OpenSSL" library (or with modified versions of
it that use the same license as the "OpenSSL" library), and distribute the
linked executables.  You must obey the GNU General Public License in all
respects for all of the code used other than "OpenSSL".  If you modify this
file, you may extend this exception to your version of the file, but you are
not obligated to do so.  If you do not wish to do so, delete this exception
statement from your version.

==> e2guardian_5.3.5.orig.tar.gz: e2guardian-5.3.5/README.md <==
# [E2Guardian](http://e2guardian.org) 

This is the final maintenance release for v5.3 production version - v5.3.5

Note that large sections of the code has been re-written and there are
significant changes to the configuration files in this release.

Note: Configuration files in this version are not backward compatable
with v4 configuration files.

Please read notes/NEWIN_v5 before installing.

**For copyright go to: http://e2guardian.org**

e2guardian is a content filtering proxy that can work in 
explicit and transparent proxy mode or as a ICAP server mode.
More information can be found in the "notes" subdirectory of the distribution, 
and the comments in the configuration and list files themselves.

e2guardian is a fork of [DansGuardian](http://dansguardian.org) and the 
maintainers fully acknowledge the work carried out by and the copyright 
of Daniel Baron and other contributors to the Dansguardian project.

Read the INSTALL for installation instructions.

## Contributing

Github: https://github.com/e2guardian

*	current development version i.e. v5.5.dev is used to develop new features
*	Bug fixes primarily occurs in the version '.dev' branch

## Bugs and Feature Requests

Github: https://github.com/e2guardian/e2guardian/issues

Codacy Badge:
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/92742338bce249c6a52739d0343dabfa)](https://www.codacy.com/app/numsys/e2guardian?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=e2guardian/e2guardian&amp;utm_campaign=Badge_Grade)

## Community

*	 Join the [Community
    Forum](https://groups.google.com/forum/#!forum/e2guardian).

## License

Copyright 2018, [Frederic Bourgeois](http://numsys.eu), [E2BN Protex](http://protex.e2bn.org) Ltd and others.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License version 2 as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

In addition, as a special exception, the copyright holders
of this work, give permission to link the code of its release of e2guardian
with the OpenSSL project's "OpenSSL" library (or with modified versions of
it that use the same license as the "OpenSSL" library), and distribute the
linked executables.  You must obey the GNU General Public License in all
respects for all of the code used other than "OpenSSL".  If you modify this
file, you may extend this exception to your version of the file, but you are
not obligated to do so.  If you do not wish to do so, delete this exception
statement from your version.
